import {
  tokens
} from "./chunk.G4YDI5AG.js";
import {
  GdsElement
} from "./chunk.WIZDAKJ5.js";
import {
  gdsCustomElement
} from "./chunk.MLXMQIEV.js";
import {
  __decorateClass,
  __privateAdd,
  __privateGet
} from "./chunk.SEHSDSX2.js";

// libs/core/src/components/menu-button/menu-button.ts
import { unsafeCSS } from "lit";
import { property } from "lit/decorators.js";
import { classMap } from "lit/directives/class-map.js";
import { ifDefined } from "lit/directives/if-defined.js";
import { literal, html as staticHtml } from "lit/static-html.js";

// libs/core/src/components/menu-button/menu-button.css?inline
var menu_button_default = `@layer tokens, a11y, core, variants, sizes, sets, disabled;

@layer tokens {
  :host {
    --_gap: 4px;

    --_padding-inline: var(--gds-space-m);
    --_padding-block: var(--gds-space-xs);

    --_color-bg: transparent;
    --_color-text: var(--gds-sys-color-primary-text);
    --_color-border: transparent;

    --_color-outline-alpha: 60%;
    --_color-outline: var(--gds-sys-color-border-stroke);

    --_font-size: 1rem;
    --_font-weight: 400;
    --_line-height: 1.25;

    display: inline-block;
    isolation: isolate;
    max-width: 100%;
    height: 100%;
  }
}

@layer core {
  .button {
    align-items: center;

    background-color: var(--_color-bg);

    border-color: var(--_color-border);
    border-style: none;
    border-bottom-style: solid;
    border-bottom-width: 2px;

    box-sizing: border-box;
    color: var(--_color-text);
    color-scheme: dark light;
    cursor: pointer;

    display: inline-flex;
    gap: var(--_gap);
    height: 100%;

    inline-size: 100%;
    justify-content: space-between;
    justify-items: center;
    outline-color: transparent;
    outline-offset: 2px;
    outline-style: solid;
    outline-width: 2px;
    padding-block: var(--_padding-block);
    padding-inline: var(--_padding-inline);
    position: relative;
    font-family: inherit;
    font-size: var(--_font-size);
    font-weight: var(--_font-weight);
    line-height: var(--_line-height);

    &:focus-visible {
      outline-color: color-mix(
        in srgb,
        var(--_color-outline),
        transparent var(--_color-outline-alpha)
      );
      border-radius: 2px;
      overflow: visible;
    }

    &:hover,
    &.selected:hover,
    &:active {
      --_color-bg: var(--gds-sys-color-base200);
      --_color-border: var(--gds-sys-color-base600);
    }

    &.selected {
      --_color-bg: var(--gds-sys-color-base100);
      --_color-border: var(--gds-sys-color-base700);
    }

    slot:not([name]) {
      display: inline-block;
      overflow: hidden;
      text-overflow: ellipsis;
      white-space: nowrap;
    }
  }
  .compact {
    display: flex;
    flex-direction: column;
    --_padding-inline: var(--gds-space-s);
    --_gap: 1px;
    font-size: 0.875rem;
    height: 56px;
    justify-content: center;

    & > slot[name] {
      order: 0;
    }
    & > slot:not([name]) {
      order: 1;
    }
  }

  a {
    text-decoration: none;
  }
}

@layer disabled {
  :disabled {
    --_color-bg: var(--gds-sys-color-container-container-disabled);
    border-color: var(--_color-bg);
    color: var(--gds-sys-color-content-content-disabled);
    pointer-events: none;
  }
}
`;

// libs/core/src/components/menu-button/menu-button.ts
var _isLink, isLink_get, _defaultRel, defaultRel_get;
var GdsMenuButton = class extends GdsElement {
  constructor() {
    super();
    __privateAdd(this, _isLink);
    __privateAdd(this, _defaultRel);
    this.disabled = false;
    this.label = "";
    this.href = "";
    this.compact = false;
    this.selected = false;
  }
  render() {
    const classes = {
      button: true,
      selected: this.selected,
      compact: this.compact
    };
    const tag = __privateGet(this, _isLink, isLink_get) ? literal`a` : literal`button`;
    return staticHtml`
      <${tag}
        class="${classMap(classes)}"
        ?disabled="${this.disabled}"
        aria-label="${this.label}"
        href=${ifDefined(__privateGet(this, _isLink, isLink_get) ? this.href : void 0)}
        target=${ifDefined(__privateGet(this, _isLink, isLink_get) ? this.target : void 0)}
        rel=${ifDefined(__privateGet(this, _isLink, isLink_get) ? this.rel || __privateGet(this, _defaultRel, defaultRel_get) : void 0)}
        download=${ifDefined(__privateGet(this, _isLink, isLink_get) ? this.download : void 0)}
      >
        <slot name="lead"></slot>
        <slot part="main-slot"></slot>
        <slot name="trail"></slot>
      </${tag}>
    `;
  }
};
_isLink = new WeakSet();
isLink_get = function() {
  return this.href.length > 0;
};
_defaultRel = new WeakSet();
defaultRel_get = function() {
  return this.target === "_blank" ? "noreferrer noopener" : void 0;
};
GdsMenuButton.styles = [tokens, unsafeCSS(menu_button_default)];
GdsMenuButton.shadowRootOptions = {
  mode: "open",
  delegatesFocus: true
};
__decorateClass([
  property({ type: Boolean, reflect: true })
], GdsMenuButton.prototype, "disabled", 2);
__decorateClass([
  property()
], GdsMenuButton.prototype, "label", 2);
__decorateClass([
  property()
], GdsMenuButton.prototype, "href", 2);
__decorateClass([
  property()
], GdsMenuButton.prototype, "target", 2);
__decorateClass([
  property()
], GdsMenuButton.prototype, "rel", 2);
__decorateClass([
  property()
], GdsMenuButton.prototype, "download", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], GdsMenuButton.prototype, "compact", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], GdsMenuButton.prototype, "selected", 2);
GdsMenuButton = __decorateClass([
  gdsCustomElement("gds-menu-button")
], GdsMenuButton);

export {
  GdsMenuButton
};
