import { GdsFormControlElement } from '../form/form-control';
import '../layout/flex';
import '../icon/icons/cross-small';
import '../icon/icons/circle-info';
import '../icon/icons/triangle-exclamation';
import '../layout/flex';
import '../layout/container';
import '../layout/card';
import '../content/text';
import '../badge';
import '../button';
/**
 * @summary A custom input element that can be used in forms.
 * @status beta
 *
 * @element gds-input
 *.
 * @slot lead - Accepts `gds-icon-[ICON_NAME]`. Use this to place an icon in the start of the field.
 * @slot trail - Accepts `gds-badge`. Use this to place a badge in the field, for displaying currency for example.
 * @slot extended-supporting-text - A longer supporting text can be placed here. It will be
 *       displayed in a panel when the user clicks the info button.
 */
export declare class GdsTextarea extends GdsFormControlElement<string> {
    #private;
    static styles: (import("lit").CSSResult | import("lit").CSSResult[])[];
    value: string;
    /**
     * The label displayed above the field
     */
    label: string;
    /**
     * Rows of the textarea
     */
    rows: number;
    private lines;
    private isDragging;
    private lastMouseY;
    /**
     * The supporting text displayed between the label and the field itself
     */
    supportingText: string;
    /**
     * Whether the supporting text should be displayed or not.
     */
    showExtendedSupportingText: boolean;
    /**
     * If the input is Disabled
     */
    disabled: boolean;
    /**
     * Whether the field should be clearable or not. Clearable fields will display a clear button when
     * the field has a value.
     */
    clearable: boolean;
    /**
     * Whether the field should be resizeable or not. If set to `false`, the field will not be resizeable.
     *
     * When `auto` (default), the field will disaplay a resize handle and will be resizeable in the vertical direction.
     *
     * The textarea is resizeable based on the `rows` attribute and the content of the textarea by default.
     *
     * @property resize
     *
     */
    resize: string;
    /**
     * The maximum number of characters allowed in the field.
     */
    maxlength: number;
    /**
     * The variant of the input field. The default variant displays a label, supporting text, and
     * extended supporting text. The floating-label variant only displays the field itself and the
     * supporting text below.
     *
     * The floating-label variant should only be used in specific cases, for example when the input field
     * is placed inside a table cell or in a space-constrained layout.
     *
     * A typical form should use the default variant.
     */
    variant: 'default' | 'floating-label';
    private elTextareaAsync;
    private elTextarea;
    private elExtendedSupportingTextSlot;
    trailSlotOccupied: boolean;
    constructor();
    connectedCallback(): void;
    disconnectedCallback(): void;
    render(): any;
    protected _getValidityAnchor(): HTMLTextAreaElement;
    private _setAutoHeight;
}
